pub struct CreateConfigInstructionArgs {
pub gating_program: Pubkey,
}Fields
gating_program: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for CreateConfigInstructionArgs
impl BorshDeserialize for CreateConfigInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for CreateConfigInstructionArgs
impl Clone for CreateConfigInstructionArgs
Sourcefn clone(&self) -> CreateConfigInstructionArgs
fn clone(&self) -> CreateConfigInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateConfigInstructionArgs
impl Debug for CreateConfigInstructionArgs
impl Eq for CreateConfigInstructionArgs
impl StructuralPartialEq for CreateConfigInstructionArgs