pub struct SetGatingProgramInstructionArgs {
pub new_gating_program: Pubkey,
}Fields
new_gating_program: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for SetGatingProgramInstructionArgs
impl BorshDeserialize for SetGatingProgramInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for SetGatingProgramInstructionArgs
impl Clone for SetGatingProgramInstructionArgs
Sourcefn clone(&self) -> SetGatingProgramInstructionArgs
fn clone(&self) -> SetGatingProgramInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for SetGatingProgramInstructionArgs
impl PartialEq for SetGatingProgramInstructionArgs
Sourcefn eq(&self, other: &SetGatingProgramInstructionArgs) -> bool
fn eq(&self, other: &SetGatingProgramInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SetGatingProgramInstructionArgs
impl StructuralPartialEq for SetGatingProgramInstructionArgs